==> dotykacka-java-api-client-0.4.6-sources.jar: pl/grizzlysoftware/dotykacka/client/v1/api/dto/Ingredient.java <==
package pl.grizzlysoftware.dotykacka.client.v1.api.dto;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * @author Bartosz Pawłowski, bpawlowski@grizzlysoftware.pl
 */
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class Ingredient {
    @JsonProperty("TOTAL_ROWS")
    private Long totalRows;
    @JsonProperty("belongstoproductId")
    private Long belongstoproductId;
    @JsonProperty("childExtId")
    private String childExtId;
    @JsonProperty("cloudid")
    private Long cloudId;
    @JsonProperty("deleted")
    private Boolean isDeleted;
    @JsonProperty("ingUnit")
    private String ingUnit;
    @JsonProperty("ingrediencemapid")
    private Long id;
    @JsonProperty("ingredienceproductId")
    private Long productId;
    @JsonProperty("origproductname")
    private String origProductName;
    @JsonProperty("parentExtId")
    private String parentExtId;
    @JsonProperty("pgKey")
    private Long pgKey;
    @JsonProperty("productUnit")
    private String productUnit;
    @JsonProperty("purchasepricewithoutvat2")
    private Integer purchasePriceWithoutVat2;
    @JsonProperty("quantity")
    private Integer quantity;
    @JsonProperty("serialVersionUID")
    private Integer serialVersionUID;
    @JsonProperty("totalsum")
    private Integer totalSum;
    @JsonProperty("treeQuantity")
    private Integer treeQuantity;
    @JsonProperty("units")
    private String units;
    @JsonProperty("versiondate")
    private Long versionDate;
}

==> dotykacka-java-api-client-0.5.4-sources.jar: pl/grizzlysoftware/dotykacka/client/v1/api/dto/Ingredient.java <==
package pl.grizzlysoftware.dotykacka.client.v1.api.dto;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * @author Bartosz Pawłowski, bpawlowski@grizzlysoftware.pl
 */
@JsonIgnoreProperties(ignoreUnknown = true)
@JsonInclude(JsonInclude.Include.NON_NULL)
public class Ingredient {
    @JsonProperty("TOTAL_ROWS")
    public Long totalRows;
    @JsonProperty("belongstoproductId")
    public Long belongstoproductId;
    @JsonProperty("childExtId")
    public String childExtId;
    @JsonProperty("cloudid")
    public Long cloudId;
    @JsonProperty("deleted")
    public Boolean isDeleted;
    @JsonProperty("ingUnit")
    public String ingUnit;
    @JsonProperty("ingrediencemapid")
    public Long id;
    @JsonProperty("ingredienceproductId")
    public Long productId;
    @JsonProperty("origproductname")
    public String origProductName;
    @JsonProperty("parentExtId")
    public String parentExtId;
    @JsonProperty("pgKey")
    public Long pgKey;
    @JsonProperty("productUnit")
    public String productUnit;
    @JsonProperty("purchasepricewithoutvat2")
    public Integer purchasePriceWithoutVat2;
    @JsonProperty("quantity")
    public Integer quantity;
    @JsonProperty("serialVersionUID")
    public Integer serialVersionUID;
    @JsonProperty("totalsum")
    public Integer totalSum;
    @JsonProperty("treeQuantity")
    public Integer treeQuantity;
    @JsonProperty("units")
    public String units;
    @JsonProperty("versiondate")
    public Long versionDate;
}
